# Changelog

## Version 0.4.5

* Add logging of long running crop/center operations
* Keep cookies during requests
* Add wait for CiteSeerX provider
* Make determining the provider more robust (issue 
  [#21](https://github.com/GjjvdBurg/paper2remarkable/issues/21))

## Version 0.4.4

* Bugfix for creating a directory on the reMarkable 
  ([#20](https://github.com/GjjvdBurg/paper2remarkable/issues/20))

## Version 0.4.3

* Add provider for CiteSeerX
* Update provider for ACM (website redesign)
* Properly use exceptions when errors occur

## Version 0.4.2

* Add provider for Proceedings of Machine Learning Research 
  ([#8](https://github.com/GjjvdBurg/paper2remarkable/issues/8))
* Add provider for NeurIPS papers 
  ([#12](https://github.com/GjjvdBurg/paper2remarkable/issues/12))

## Version 0.4.1

* Add support for alternative arXiv URLS
* Always run all redirects on specified urls before choosing provider

## Version 0.4.0

* Refactor code to make it a real Python package
* Rename to ``paper2remarkable``
